# Obsolescence Risk Management
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management#overview)
  * [What is Obsolescence Risk Management?](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management#what-is-obsolescence-risk-management?)
  * [Why is Obsolescence Risk Management Relevant?](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management#why-is-obsolescence-risk-management-relevant?)
  * [Which SAP LeanIX Products are Needed for Obsolescence Risk Management?](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management#which-sap-leanix-products-are-needed-for-obsolescence-risk-management?)
  * [How to Manage Obsolescence Risk with SAP LeanIX](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management#how-to-manage-obsolescence-risk-with-sap-leanix)
  * [Step-by-Step Guide](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management#step-by-step-guide)


Learn why obsolescence risk management matters, how to discover risks associated with obsolete technology, how to assess their business impact, and how to efficiently manage and address them with SAP LeanIX.
